"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = LoginLink;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _reactIntl = require("react-intl");
var _reactRouterDom = require("react-router-dom");
var _LoginLink = _interopRequireDefault(require("../../../styles/cspace-ui/LoginLink.css"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/* global window */

const propTypes = {
  isExpired: _propTypes.default.bool,
  openNewWindow: _propTypes.default.bool,
  onNewWindowOpen: _propTypes.default.func,
  onNewWindowError: _propTypes.default.func
};
const defaultProps = {
  isExpired: false,
  openNewWindow: false,
  onNewWindowOpen: null,
  onNewWindowError: null
};
const messages = (0, _reactIntl.defineMessages)({
  label: {
    "id": "loginLink.label",
    "defaultMessage": "Sign in"
  },
  renew: {
    "id": "loginLink.renew",
    "defaultMessage": "Renew session"
  }
});
function LoginLink(props) {
  const {
    isExpired,
    onNewWindowOpen,
    onNewWindowError,
    openNewWindow
  } = props;
  const authorizePageUrl = '/authorize';
  let handleClick;
  if (openNewWindow) {
    handleClick = event => {
      event.preventDefault();
      const popupWidth = 550;
      const popupHeight = 800;
      const screenWidth = window.screen.width;
      const screenHeight = window.screen.height;
      const left = (screenWidth - popupWidth) / 2;
      const top = (screenHeight - popupHeight) / 2;
      const popup = window.open(authorizePageUrl, 'cspace-login', `width=${popupWidth},height=${popupHeight},left=${left},top=${top}`);
      if (popup) {
        if (onNewWindowOpen) {
          onNewWindowOpen();
        }
      } else if (onNewWindowError) {
        onNewWindowError();
      }
    };
  }
  const message = isExpired ? messages.renew : messages.label;
  return /*#__PURE__*/_react.default.createElement(_reactRouterDom.Link, {
    className: _LoginLink.default.common,
    to: authorizePageUrl,
    onClick: handleClick
  }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, message));
}
LoginLink.propTypes = propTypes;
LoginLink.defaultProps = defaultProps;