"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = AuthorizedPage;
var _react = _interopRequireWildcard(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _immutable = _interopRequireDefault(require("immutable"));
var _reactIntl = require("react-intl");
var _reactRouterDom = require("react-router-dom");
var _Notification = _interopRequireDefault(require("../notification/Notification"));
var _AuthorizedPage = _interopRequireDefault(require("../../../styles/cspace-ui/AuthorizedPage.css"));
var _LoginForm = _interopRequireDefault(require("../../../styles/cspace-ui/LoginForm.css"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); } /* global window */
const propTypes = {
  isPending: _propTypes.default.bool,
  isSuccess: _propTypes.default.bool,
  error: _propTypes.default.instanceOf(_immutable.default.Map),
  history: _propTypes.default.shape({
    replace: _propTypes.default.func.isRequired
  }).isRequired,
  location: _propTypes.default.shape({
    search: _propTypes.default.string
  }).isRequired,
  loginWithAuthCodeRequest: _propTypes.default.func.isRequired,
  username: _propTypes.default.string
};
const contextTypes = {
  config: _propTypes.default.shape({
    recordTypes: _propTypes.default.object
  }).isRequired
};
const messages = (0, _reactIntl.defineMessages)({
  pending: {
    "id": "authorizedPage.pending",
    "defaultMessage": "Finishing sign in..."
  },
  success: {
    "id": "authorizedPage.success",
    "defaultMessage": "Signed in as {username}."
  },
  error: {
    "id": "authorizedPage.error",
    "defaultMessage": "Sign in failed."
  },
  retry: {
    "id": "authorizedPage.retry",
    "defaultMessage": "Try again"
  },
  ERR_AUTH_CODE_REQUEST_NOT_FOUND: {
    "id": "authorizedPage.ERR_AUTH_CODE_REQUEST_NOT_FOUND",
    "defaultMessage": "Sign in failed. The authorization code does not belong to an active sign in request."
  },
  ERR_BAD_REQUEST: {
    "id": "authorizedPage.ERR_BAD_REQUEST",
    "defaultMessage": "Sign in failed. The CollectionSpace server received a bad request."
  },
  ERR_ACCOUNT_INACTIVE: {
    "id": "authorizedPage.ERR_ACCOUNT_INACTIVE",
    "defaultMessage": "Sign in failed. The account is inactive."
  },
  ERR_ACCOUNT_INVALID: {
    "id": "authorizedPage.ERR_ACCOUNT_INVALID",
    "defaultMessage": "Sign in failed. The account is in an invalid state."
  },
  ERR_ACCOUNT_NOT_FOUND: {
    "id": "authorizedPage.ERR_ACCOUNT_NOT_FOUND",
    "defaultMessage": "Sign in failed. Account not found."
  },
  ERR_INVALID_CREDENTIALS: {
    "id": "authorizedPage.ERR_INVALID_CREDENTIALS",
    "defaultMessage": "Sign in failed. Incorrect username/password."
  },
  ERR_NETWORK: {
    "id": "authorizedPage.ERR_NETWORK",
    "defaultMessage": "Sign in failed. Unable to reach the CollectionSpace server."
  },
  ERR_WRONG_TENANT: {
    "id": "authorizedPage.ERR_WRONG_TENANT",
    "defaultMessage": "Sign in failed. The user is not registered to this CollectionSpace tenant."
  }
});
const handleSuccess = props => {
  if (window.opener && window.opener.onAuthorizationSuccess != null) {
    window.opener.onAuthorizationSuccess();
    window.close();
    return;
  }
  const {
    history,
    landingPath
  } = props;
  history.replace(landingPath);
};
const renderStatus = (username, isSuccess, isPending) => {
  let messageKey;
  if (isPending) {
    messageKey = 'pending';
  } else if (isSuccess) {
    messageKey = 'success';
  }
  if (!messageKey) {
    return null;
  }
  return /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages[messageKey], {
    values: {
      username
    }
  })));
};
const renderError = (error, isPending) => {
  if (isPending || !error) {
    return undefined;
  }
  const messageKey = error.get('code') || 'error';
  return /*#__PURE__*/_react.default.createElement(_Notification.default, {
    id: "authorizedPage.error",
    items: [{
      message: messages[messageKey] || messages.error
    }],
    showCloseButton: false,
    status: "error"
  });
};
const renderReturnLink = error => {
  if (!error) {
    return undefined;
  }
  return /*#__PURE__*/_react.default.createElement("p", null, /*#__PURE__*/_react.default.createElement(_reactRouterDom.Link, {
    to: "/login"
  }, /*#__PURE__*/_react.default.createElement(_reactIntl.FormattedMessage, messages.retry)));
};
function AuthorizedPage(props, context = {}) {
  const {
    config
  } = context;
  const {
    error,
    isPending,
    isSuccess,
    location,
    loginWithAuthCodeRequest,
    username
  } = props;
  (0, _react.useEffect)(() => {
    const {
      search
    } = location;
    const params = new URLSearchParams(search);
    const authCodeRequestId = params.get('state');
    const authCode = params.get('code');
    loginWithAuthCodeRequest(config, authCodeRequestId, authCode);
  }, []);
  (0, _react.useEffect)(() => {
    if (isSuccess) {
      handleSuccess(props);
    }
  }, [isSuccess]);
  let contentClassName;
  if (isPending) {
    contentClassName = _LoginForm.default.pending;
  } else if (isSuccess) {
    contentClassName = _LoginForm.default.success;
  } else {
    contentClassName = _LoginForm.default.common;
  }
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _AuthorizedPage.default.common
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: contentClassName
  }, renderStatus(username, isSuccess, isPending), renderError(error, isPending), renderReturnLink(error)));
}
AuthorizedPage.propTypes = propTypes;
AuthorizedPage.contextTypes = contextTypes;